@@ -8,7 +8,7 @@
 use proc_macro::TokenStream;
 use quote::quote;
 use syn::parse_macro_input;
-mod util;
+mod flow_util;
 use syn::{ExprCall, ItemFn, ItemMod};
 
 /// execute a function after the test is executed even if the test failled
@@ -24,7 +24,7 @@ use syn::{ExprCall, ItemFn, ItemMod};
 ///    } else if i == 2 {
 ///        return Ok(());
 ///    } else {
-///        panic!("oh no!")
+///        panic!("oh no!");
 ///        Ok(())
 ///    }
 /// }
@@ -40,13 +40,13 @@ use syn::{ExprCall, ItemFn, ItemMod};
 /// {panic statement}
 /// I did 66 thing(s)
 /// ```
-/// 
+///
 #[proc_macro_attribute]
 pub fn after(_metadata: TokenStream, input: TokenStream) -> TokenStream {
     let mut function = parse_macro_input!(input as ItemFn);
     let args = parse_macro_input!(_metadata as ExprCall);
 
-    util::add_fn_after(&mut function, &args)
+    flow_util::add_fn_after(&mut function, &args)
 }
 
 /// execute a function before the test start
@@ -75,12 +75,14 @@ pub fn before(_metadata: TokenStream, input: TokenStream) -> TokenStream {
     let mut function = parse_macro_input!(input as ItemFn);
     let args = parse_macro_input!(_metadata as ExprCall);
 
-    util::add_fn_before(&mut function, &args)
+    flow_util::add_fn_before(&mut function, &args)
 }
 
 /// for each tests of a module execute the function before the test start
 /// # Examples
 /// ```
+/// use s_test_fixture::before_each;
+/// 
 /// #[before_each(function_to_run(2))]
 /// mod tests{
 ///     #[test]
@@ -89,7 +91,7 @@ pub fn before(_metadata: TokenStream, input: TokenStream) -> TokenStream {
 ///         assert_eq!(a,2);
 ///         println!("ending");
 ///     }
-/// 
+///
 ///     #[test]
 ///     fn another_test() {
 ///         let a = 2;
@@ -106,7 +108,7 @@ pub fn before(_metadata: TokenStream, input: TokenStream) -> TokenStream {
 pub fn before_each(_metadata: TokenStream, input: TokenStream) -> TokenStream {
     let mut test_mod = parse_macro_input!(input as ItemMod);
     let args = parse_macro_input!(_metadata as ExprCall);
-    util::add_fn_before_each(&mut test_mod, &args);
+    flow_util::add_fn_before_each(&mut test_mod, &args);
     TokenStream::from(quote! {
         #test_mod
     })
@@ -115,6 +117,8 @@ pub fn before_each(_metadata: TokenStream, input: TokenStream) -> TokenStream {
 /// for each tests of a module execute the function after the test end even if the test failled
 /// # Examples
 /// ```
+/// use s_test_fixture::after_each;
+/// 
 /// #[after_each(function_to_run(66))]
 /// mod tests{
 ///     #[test]
@@ -126,11 +130,11 @@ pub fn before_each(_metadata: TokenStream, input: TokenStream) -> TokenStream {
 ///         } else if i == 2 {
 ///             return Ok(());
 ///         } else {
-///             panic!("oh no!")
+///             panic!("oh no!");
 ///             Ok(())
 ///          }
 ///     }
-/// 
+///
 ///     #[test]
 ///     fn another_test() -> Result<(), ()> {
 ///         println!("before");
@@ -140,7 +144,7 @@ pub fn before_each(_metadata: TokenStream, input: TokenStream) -> TokenStream {
 ///         } else if i == 2 {
 ///             return Ok(());
 ///         } else {
-///             panic!("oh no!")
+///             panic!("oh no!");
 ///             Ok(())
 ///          }
 ///     }
@@ -155,7 +159,7 @@ pub fn before_each(_metadata: TokenStream, input: TokenStream) -> TokenStream {
 pub fn after_each(_metadata: TokenStream, input: TokenStream) -> TokenStream {
     let mut test_mod = parse_macro_input!(input as ItemMod);
     let args = parse_macro_input!(_metadata as ExprCall);
-    util::add_fn_after_each(&mut test_mod, &args);
+    flow_util::add_fn_after_each(&mut test_mod, &args);
     TokenStream::from(quote! {
         #test_mod
     })
